/*
 * cc urlGen.c -o urlGen -lm
 * Generates a list of URLs to request from Kurt(m)'s web server.
 * Uses exponential distribution with mean value given by beta, a passed
 * in parameter to determine file size requested.  
 * So 'urlGen 250 1000 localhost' will generate 1000 urls to request of
 * localhost, with mostly files smaller than 250k but perhaps a few 
 * significantly larger.
 */

#include <stdlib.h> 
#include <math.h> // for log()

double get_exp(double beta){
  //returns -beta*ln(U) where U is uniformly distributed on (0,1]
  double randNum;
  
  //make sure randNum!=0 since ln(0)=-inf, an error
  do{
    randNum=drand48();
  }while (randNum==0);
  
  return (-(beta * log (randNum)));
}

void usage(){
  printf("Usage: fileGen meansize num host\n");
  exit(1);
}

int main(int argc, char* argv[]){
  int beta, num, fileSize;
  char *host;

  if (argc != 4)
    usage();
  beta=atoi(argv[1]);
  num=atoi(argv[2]);
  if (beta < 0 || num < 0)
    usage();

  host=argv[3];
  
  for (;num > 0; num--){
    fileSize = (int)get_exp(beta);
    if (!fileSize) /* don't allow 0 byte requests */
	fileSize=1;
    if (fileSize > 8192) /* don't request more than 8 megs */
	fileSize=8192;
    printf("http://%s/file%ik.html\n",host, fileSize);
  }
  
}
