#!/bin/sh
##############################################################################
# testLocale.sh: verifies correctness of the locale-specific installation of
#                squid
#
# Reads input from a file of the form $LANG:$SQUIDLANG.  For example, the 
# a few lines of the file are:
# C:English
# POSIX:English
# cs_CZ.ISO8859-2:Czech
# de_CH:German
# This script reads a line of this file, sets the language ENV variable
# to the bit before the ':' and makes sure that the squid packaging correctly
# links to the directory given by the bit after the ':'.  So, for example,
# it would set LANG=de_CH, install squid, and then verify that errors is
# linked to German.  Results of this are saved in the file "RESULTS", of 
# course.
##############################################################################

MAP="`pwd`/lang2squid.map"
RESULTS=RESULTS
FAILED=0
SQUID_BIN=/usr/internet/squid/bin/squid

##########################################################################
# verify_starts()
# Tries to start squid.  Returns 0 iff squid starts successfully.
##########################################################################
verify_starts() {
    $SQUID_BIN -sY	
    count=0; while [ $count -lt 30 ]; do
	sleep 1
	$SQUID_BIN -k check 2> /dev/null
	if [ $? -eq 0 ]; then
	    break
	fi
	count=`expr $count + 1`
    done
    if [ $count -lt 30 ]; then
	return 0;
    else
	return 1;
    fi
}
##########################################################################
# main ()
##########################################################################

if [ -f $MAP ] ; then
    exec < $MAP
else
    echo "No map file found."
    exit 1
fi

read LINE

while [ -n "$LINE" ] ; do
    _LANG=`echo $LINE |sed 's/:.*$//'`
    _SQUID=`echo $LINE |sed 's/^.*://'`
    LANG=$_LANG custom -i -p SCO:Squid -z `pwd`
    /bin/echo -n "Install of $_LANG " >> "$RESULTS"
    # Here's a gnarly line.  If all is right, errors should be linked to
    # the language appropriate directory in /usr/internet/squid/etc/locale.
    # So, we examine the link, and chop off the bit that shows what it is 
    # pointing to. This looks like "/usr/internet/squid/etc/locale/$LANG"
    # What we care about is the $LANG bit, which looks like English or
    # Spanish.  The second awk bit chops off just this piece, which is
    # assigned to _ERRORS.
    _ERRORS=`ls -l /usr/internet/squid/etc/errors |awk '{print $NF}' \
		|awk -F/ '{print $NF}'`
    if [ "$_ERRORS" = "$_SQUID" ]; then
	/bin/echo "passed." >> "$RESULTS"
    else
	FAILED=1
	/bin/echo "FAILED -- expected $_SQUID, got $_ERRORS." >> "$RESULTS"
    fi
    verify_starts
    if [ $? -ne 0 ]; then
	/bin/echo "----Squid FAILED to start for $_LANG----" \
				>> "$RESULTS"
	FAILED=1
    fi
    custom -r SCO:Squid
    read LINE
done

# Cleanup all the disowned content.
rm -rf /usr/internet/squid

if [ $FAILED -ne 0 ]; then
    echo "Locale tests *FAILED*.  See file RESULTS for details."
else
    echo "Locale tests passed."
fi
